==> monica-3.7.0p0.tgz: www/monica/bootstrap/cache/packages.php <==
<?php return array (
  'asbiin/laravel-adorable' => 
  array (
    'aliases' => 
    array (
      'LaravelAdorable' => 'LaravelAdorable\\Facades\\LaravelAdorable',
    ),
    'providers' => 
    array (
      0 => 'LaravelAdorable\\LaravelAdorableServiceProvider',
    ),
  ),
  'asbiin/laravel-webauthn' => 
  array (
    'providers' => 
    array (
      0 => 'LaravelWebauthn\\SingletonServiceProvider',
      1 => 'LaravelWebauthn\\WebauthnServiceProvider',
    ),
  ),
  'creativeorange/gravatar' => 
  array (
    'providers' => 
    array (
      0 => 'Creativeorange\\Gravatar\\GravatarServiceProvider',
    ),
    'aliases' => 
    array (
      'Gravatar' => 'Creativeorange\\Gravatar\\Facades\\Gravatar',
    ),
  ),
  'facade/ignition' => 
  array (
    'providers' => 
    array (
      0 => 'Facade\\Ignition\\IgnitionServiceProvider',
    ),
    'aliases' => 
    array (
      'Flare' => 'Facade\\Ignition\\Facades\\Flare',
    ),
  ),
  'intervention/image' => 
  array (
    'providers' => 
    array (
      0 => 'Intervention\\Image\\ImageServiceProvider',
    ),
    'aliases' => 
    array (
      'Image' => 'Intervention\\Image\\Facades\\Image',
    ),
  ),
  'laravel/cashier' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Cashier\\CashierServiceProvider',
    ),
  ),
  'laravel/passport' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Passport\\PassportServiceProvider',
    ),
  ),
  'laravel/socialite' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Socialite\\SocialiteServiceProvider',
    ),
    'aliases' => 
    array (
      'Socialite' => 'Laravel\\Socialite\\Facades\\Socialite',
    ),
  ),
  'laravel/ui' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Ui\\UiServiceProvider',
    ),
  ),
  'laravolt/avatar' => 
  array (
    'providers' => 
    array (
      0 => 'Laravolt\\Avatar\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Avatar' => 'Laravolt\\Avatar\\Facade',
    ),
  ),
  'mariuzzo/laravel-js-localization' => 
  array (
    'providers' => 
    array (
      0 => 'Mariuzzo\\LaravelJsLocalization\\LaravelJsLocalizationServiceProvider',
    ),
  ),
  'monicahq/laravel-cloudflare' => 
  array (
    'providers' => 
    array (
      0 => 'Monicahq\\Cloudflare\\TrustedProxyServiceProvider',
    ),
  ),
  'monicahq/laravel-sabre' => 
  array (
    'providers' => 
    array (
      0 => 'LaravelSabre\\LaravelSabreServiceProvider',
    ),
  ),
  'nesbot/carbon' => 
  array (
    'providers' => 
    array (
      0 => 'Carbon\\Laravel\\ServiceProvider',
    ),
  ),
  'pragmarx/countries-laravel' => 
  array (
    'providers' => 
    array (
      0 => 'PragmaRX\\CountriesLaravel\\Package\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Countries' => 'PragmaRX\\CountriesLaravel\\Package\\Facade',
    ),
  ),
  'pragmarx/google2fa-laravel' => 
  array (
    'providers' => 
    array (
      0 => 'PragmaRX\\Google2FALaravel\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Google2FA' => 'PragmaRX\\Google2FALaravel\\Facade',
    ),
  ),
  'sentry/sentry-laravel' => 
  array (
    'providers' => 
    array (
      0 => 'Sentry\\Laravel\\ServiceProvider',
      1 => 'Sentry\\Laravel\\Tracing\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Sentry' => 'Sentry\\Laravel\\Facade',
    ),
  ),
  'stevebauman/location' => 
  array (
    'providers' => 
    array (
      0 => 'Stevebauman\\Location\\LocationServiceProvider',
    ),
    'aliases' => 
    array (
      'Location' => 'Stevebauman\\Location\\Facades\\Location',
    ),
  ),
  'vinkla/hashids' => 
  array (
    'providers' => 
    array (
      0 => 'Vinkla\\Hashids\\HashidsServiceProvider',
    ),
    'aliases' => 
    array (
      'Hashids' => 'Vinkla\\Hashids\\Facades\\Hashids',
    ),
  ),
  'vluzrmos/language-detector' => 
  array (
    'providers' => 
    array (
      0 => 'Vluzrmos\\LanguageDetector\\Providers\\LanguageDetectorServiceProvider',
    ),
  ),
  'werk365/etagconditionals' => 
  array (
    'providers' => 
    array (
      0 => 'Werk365\\EtagConditionals\\EtagConditionalsServiceProvider',
    ),
    'aliases' => 
    array (
      'EtagConditionals' => 'Werk365\\EtagConditionals\\Facades\\EtagConditionals',
    ),
  ),
);

==> monica-4.1.2p0.tgz: www/monica/bootstrap/cache/packages.php <==
<?php return array (
  'asbiin/laravel-adorable' => 
  array (
    'aliases' => 
    array (
      'LaravelAdorable' => 'LaravelAdorable\\Facades\\LaravelAdorable',
    ),
    'providers' => 
    array (
      0 => 'LaravelAdorable\\LaravelAdorableServiceProvider',
    ),
  ),
  'asbiin/laravel-webauthn' => 
  array (
    'providers' => 
    array (
      0 => 'LaravelWebauthn\\WebauthnServiceProvider',
    ),
  ),
  'creativeorange/gravatar' => 
  array (
    'providers' => 
    array (
      0 => 'Creativeorange\\Gravatar\\GravatarServiceProvider',
    ),
    'aliases' => 
    array (
      'Gravatar' => 'Creativeorange\\Gravatar\\Facades\\Gravatar',
    ),
  ),
  'intervention/image' => 
  array (
    'providers' => 
    array (
      0 => 'Intervention\\Image\\ImageServiceProvider',
    ),
    'aliases' => 
    array (
      'Image' => 'Intervention\\Image\\Facades\\Image',
    ),
  ),
  'laravel/cashier' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Cashier\\CashierServiceProvider',
    ),
  ),
  'laravel/passport' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Passport\\PassportServiceProvider',
    ),
  ),
  'laravel/socialite' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Socialite\\SocialiteServiceProvider',
    ),
    'aliases' => 
    array (
      'Socialite' => 'Laravel\\Socialite\\Facades\\Socialite',
    ),
  ),
  'laravel/ui' => 
  array (
    'providers' => 
    array (
      0 => 'Laravel\\Ui\\UiServiceProvider',
    ),
  ),
  'laravolt/avatar' => 
  array (
    'providers' => 
    array (
      0 => 'Laravolt\\Avatar\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Avatar' => 'Laravolt\\Avatar\\Facade',
    ),
  ),
  'mariuzzo/laravel-js-localization' => 
  array (
    'providers' => 
    array (
      0 => 'Mariuzzo\\LaravelJsLocalization\\LaravelJsLocalizationServiceProvider',
    ),
  ),
  'monicahq/laravel-cloudflare' => 
  array (
    'providers' => 
    array (
      0 => 'Monicahq\\Cloudflare\\TrustedProxyServiceProvider',
    ),
  ),
  'monicahq/laravel-sabre' => 
  array (
    'providers' => 
    array (
      0 => 'LaravelSabre\\LaravelSabreServiceProvider',
    ),
  ),
  'nesbot/carbon' => 
  array (
    'providers' => 
    array (
      0 => 'Carbon\\Laravel\\ServiceProvider',
    ),
  ),
  'nunomaduro/termwind' => 
  array (
    'providers' => 
    array (
      0 => 'Termwind\\Laravel\\TermwindServiceProvider',
    ),
  ),
  'pragmarx/google2fa-laravel' => 
  array (
    'providers' => 
    array (
      0 => 'PragmaRX\\Google2FALaravel\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Google2FA' => 'PragmaRX\\Google2FALaravel\\Facade',
    ),
  ),
  'rinvex/countries' => 
  array (
    'providers' => 
    array (
      0 => 'Rinvex\\Country\\Providers\\CountryServiceProvider',
    ),
  ),
  'sentry/sentry-laravel' => 
  array (
    'providers' => 
    array (
      0 => 'Sentry\\Laravel\\ServiceProvider',
      1 => 'Sentry\\Laravel\\Tracing\\ServiceProvider',
    ),
    'aliases' => 
    array (
      'Sentry' => 'Sentry\\Laravel\\Facade',
    ),
  ),
  'stevebauman/location' => 
  array (
    'providers' => 
    array (
      0 => 'Stevebauman\\Location\\LocationServiceProvider',
    ),
    'aliases' => 
    array (
      'Location' => 'Stevebauman\\Location\\Facades\\Location',
    ),
  ),
  'vinkla/hashids' => 
  array (
    'aliases' => 
    array (
      'Hashids' => 'Vinkla\\Hashids\\Facades\\Hashids',
    ),
    'providers' => 
    array (
      0 => 'Vinkla\\Hashids\\HashidsServiceProvider',
    ),
  ),
  'vluzrmos/language-detector' => 
  array (
    'providers' => 
    array (
      0 => 'Vluzrmos\\LanguageDetector\\Providers\\LanguageDetectorServiceProvider',
    ),
  ),
  'werk365/etagconditionals' => 
  array (
    'providers' => 
    array (
      0 => 'Werk365\\EtagConditionals\\EtagConditionalsServiceProvider',
    ),
    'aliases' => 
    array (
      'EtagConditionals' => 'Werk365\\EtagConditionals\\Facades\\EtagConditionals',
    ),
  ),
);
